<html>
<header>
<title>{% block title %}Django Photos{% endblock %}
</header>
<body>
<ul>
<li><a href="{% url albums %}" >List of albums</a></li>
<li><a href="{% url photos %}" >List of photos</a></li>
</ul>
{% block content %}
<h1>Nothing to see!</h1>
<h3>This is the base.html template.</h3>
{% endblock %}
</body>
</html>