{% extends "photos/base.html" %}

{% load thumbnail %}

{% block title %}{{block.super}} - List of Albums{% endblock %}

{% block content %}
{% if user %}
<h1>List of albums for user {{user}}.</h1>
{% else %}
<h1>List of albums</h1>
{% endif %}


<ul>
{% for album in object_list %}
<li><a href="{{ album.get_absolute_url }}">{{ album }}</a><br />
{% for photo in album.get_photos|slice:":3" %}
<a href="{% url photo-album-detail album.id photo.id %}"><img src="{% thumbnail photo.photo 100x100 crop quality=50 %}" description="{{ photo.description }}" /></a> 
{% endfor %}
{% empty %}
<li><h2>No albums to see.</h2></li>
{% endfor %}
</ul>

{% endblock %}