{% extends "photos/base.html" %}
{% load thumbnail %}

{% block title %}{{block.super}} - List of Photos{% endblock %}

{% block content %}

{% if user %}
<h1>Photos from {{ user }}</h1>
{% else %}
<h1>Photos</h1> 
{% endif %}

<ul>
{% for photo in object_list %}
<li><a href="{{photo.get_absolute_url}}"><img src="{% thumbnail photo.photo 250x250 crop quality=50 %}" /></a></li>
{% endfor %}
</ul>

{% endblock %}