{% extends "photos/base.html" %}
{% load thumbnail %}
{% block title %}{{block.super}} - Album{% endblock %}

{% block content %}
<h1>Album from {{ album.user }}</h1>

<ul>
{% for photo in object.get_photos %}
<li><img src="{% thumbnail photo.photo 150x150 crop quality=50 %}" /></li>
{% endfor %}
</ul>
{% endblock %}